PaymentInfo class sealed

Available extensions
Annotations
  • @freezed

Constructors

PaymentInfo({required PaymentStatus status, required PayAmount amount, required int expiresAt, required MerchantInfo merchant, BuyerInfo? buyer})
const
factory
PaymentInfo.fromJson(Map<String, dynamic> json)
factory

Properties

amount PayAmount
no setterinherited
buyer BuyerInfo?
no setterinherited
copyWith → $PaymentInfoCopyWith<PaymentInfo>
Create a copy of PaymentInfo with the given fields replaced by the non-null parameter values.
no setterinherited
expiresAt int
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
merchant MerchantInfo
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status PaymentStatus
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_PaymentInfo value)) → TResult

Available on PaymentInfo, provided by the PaymentInfoPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_PaymentInfo value)?) → TResult?

Available on PaymentInfo, provided by the PaymentInfoPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_PaymentInfo value)?, {required TResult orElse()}) → TResult

Available on PaymentInfo, provided by the PaymentInfoPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(PaymentStatus status, PayAmount amount, int expiresAt, MerchantInfo merchant, BuyerInfo? buyer)?, {required TResult orElse()}) → TResult

Available on PaymentInfo, provided by the PaymentInfoPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this PaymentInfo to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(PaymentStatus status, PayAmount amount, int expiresAt, MerchantInfo merchant, BuyerInfo? buyer)) → TResult

Available on PaymentInfo, provided by the PaymentInfoPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(PaymentStatus status, PayAmount amount, int expiresAt, MerchantInfo merchant, BuyerInfo? buyer)?) → TResult?

Available on PaymentInfo, provided by the PaymentInfoPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited